// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: workarea.h,v 1.8 1998/10/09 14:49:20 jochen Exp $



#ifndef KROT_WORKAREA_H
#define KROT_WORKAREA_H



#include "krotData.h"
#include "transition.h"

#include <qwidget.h>

#include <sys/types.h>


class DrawArea;
class ScrollBar64;

/**
 * This is a working area canvas, consisting of a horizontal scrollbar and
 * a drawing area.
 *
 * @short Work area canvas.
 * @author Jochen Kpper
 * @version $Id: workarea.h,v 1.8 1998/10/09 14:49:20 jochen Exp $
 */
class WorkArea : public QWidget
{
    Q_OBJECT

public:

    /**
     * Default Constructor.
     *
     * @param parent Passed to QWidget constructor.
     * @param name Passed to QWidget constructor.
     */
    WorkArea( KRotData *krotdata, QWidget *parent=0, const char *name=0 );


protected slots:

    void newAssignment( const AssignedFrequency& ass );

    /**
     * The global start/stop limits are changed.
     *
     * @param start Lowest frequency of all sets.
     * @param stop  Highest frequency of all sets.
     */
    void limits( const int64_t start, const int64_t stop );

    void setAveraging( const unsigned int avg );

    /**
     * @param freq Actual position of the mouse pointer in frequency units.
     */
    void setFreq( const int64_t freq );

    /**
     * Set display and scrollbar to the given position.
     *
     * @param pos Scrollbar value to go to.
     */
    void setPosition( const int64_t pos );
    
signals:

    /**
     * Sends every assignment made to the world.
     * These assignment need to be stored and should be editable and saveable.
     */
    void assignment( const AssignedFrequency& ass );

    /**
     * @param freq Actual position of the mouse pointer in frequency units.
     */
    void freq( const int64_t freq );
    
    /**
     * Message to user.
     *
     * @param msg Message to show.
     */
    void message( const char *msg );
    

protected:

    /**
     * Actual averaging value - this is used after the user changed the combobox
     * value to really follow the change (drawarea + scrollbar).
     */
    unsigned int average;

    int64_t first;

    KRotData *krotData;

    int64_t last;

    DrawArea *drawarea;

    ScrollBar64 *scrollbar;
};



#include <workarea_inline.h>


#endif
